/*country fiscal federalism data*/

clear
cd "C:\Users\F001CKB\Documents\American Exceptionalism Revisited"
use fiscfed5
set more off
#delimit ;
log using fiscfed5.txt, t replace;

sort id year;

xtset id year;

gen lnpop=ln(pop);
gen lnpopul=ln(population);
gen lnunits=ln(1+units);
gen lnmdm=ln(mdmh);
gen lnarea=ln(area);
gen lnsec=ln(secmov+1);

gen fiscunits4=fiscfed4*lnunits;
gen fischerf=fiscfed4*herf;

sort id year;

replace gdp=gdp/1000;
replace rgdpch=rgdpch/1000;
replace year=year-1950;
replace imf=imf/100;

gen postsoc=0;
replace postsoc=1 if yrsoctrans>0;
sort id year;
xi i.year;

summarize generalg postsoc lnmdm solt imf aged ethfrac relfrac totals cggdp iggdp tsubgdp stsbgdp cgwgdp eget nethfrac langfrac nrelfrac fiscfed fiscfed2 fiscfed4 lnunits units fiscunits4 herf fischerf lnpop smd eumem gdp trade rgdpch openk kg yrsoctrans postsoc codecision1 codecision2 codecision3 year;
centile fiscfed4 units herf, centile(10 50 90);
hist herf, xtitle("Herfindahl Index of Regional Populations");
graph export "herf.eps", replace;
corr nethfrac nrelfrac langfrac ethfrac relfrac;
corr generalg kg totals cggdp iggdp tsubgdp stsbgdp cgwgdp eget;

/*L.fiscunits4, fiscfed4, decunits4, fiscdec4 depvars*/

gen fiscdec4=fiscfed4*taxdec/100;
gen decunits4=fiscdec4*lnunits;
gen decherf=fiscdec4*herf;
summarize fiscdec4 decunits4 decherf;
centile fiscdec4, centile(10 50 90);
preserve;
collapse (mean) fiscunits4 fiscfed4 fiscdec4 decunits4 fischerf decherf nethfrac nrelfrac langfrac lnpop lnarea, by(id);
summarize fiscunits4 fiscfed4 fiscdec4 decunits4 nethfrac nrelfrac langfrac lnpop;
tobit fiscunits4 nethfrac nrelfrac langfrac lnpop lnarea , ll(0) ul(1);
tobit fiscfed4 nethfrac nrelfrac langfrac lnpop lnarea , ll(0) ul(1);
tobit fiscdec4 nethfrac nrelfrac langfrac lnpop lnarea, ll(0) ul(1);
tobit decunits4 nethfrac nrelfrac langfrac lnpop lnarea, ll(0) ul(1);
restore;
tobit fiscunits4 nethfrac nrelfrac langfrac lnpop lnarea if year==0, ll(0) ul(1);

/*gov't consumption depvar*/

regress generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.lnunits L.fiscunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch year ;
predict err if e(sample), resid;
regress err L.fiscfed4 L.lnunits L.fiscunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.err;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.lnunits L.fiscunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch year, pairwise ;
test L.fiscfed4+1.886*L.fiscunits4=0;
test L.fiscfed4+3.524*L.fiscunits4=0;
test L.lnunits+0.223*L.fiscunits4=0;
test L.lnunits+0.564*L.fiscunits4=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.lnunits L.fiscunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch year if L.imf~=. & L.aged~=., pairwise ;

/*using herfindahl index of regional populations*/
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch year, pairwise ;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;

/*incorporating tax decentralization*/

xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscdec4 L.lnunits L.decunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged year, pairwise ;
test L.fiscdec4+1.886*L.decunits4=0;
test L.fiscdec4+3.524*L.decunits4=0;
test L.lnunits+0.2597*L.decunits4=0;
xtpcse generalg L.generalg L2.generalg L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L.aged year, pairwise ;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
predict xb if e(sample), xb;
gen resid=generalg-xb;
drop xb;
/*baseline with just lags & trend*/
xtpcse generalg L.generalg L2.generalg year if resid~=., pairwise;
/*unit root checks*/
xtunitroot fisher generalg if resid~=., dfuller demean lags(2) trend;
xtunitroot fisher resid , dfuller lags(0);
xtpcse generalg L.generalg L2.generalg L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L.aged L.imf year, pairwise ;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
predict xb;
/*baseline with just lags & trend*/
xtpcse generalg L.generalg L2.generalg year if xb~=., pairwise;
drop xb;
xtpcse generalg L.generalg L2.generalg L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L.aged L.imf nethfrac nrelfrac langfrac year, pairwise ;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
predict xb;
/*baseline with just lags & trend*/
xtpcse generalg L.generalg L2.generalg year if xb~=., pairwise;
drop xb;

/*more control variables*/

xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.lnunits L.fiscunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.aged year , pairwise;
test L.fiscfed4+1.886*L.fiscunits4=0;
test L.fiscfed4+3.524*L.fiscunits4=0;
test L.lnunits+0.223*L.fiscunits4=0;
test L.lnunits+0.564*L.fiscunits4=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.aged year , pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.lnunits L.fiscunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.aged year if L.imf~=., pairwise;

xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.lnunits L.fiscunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.aged L.imf year, pairwise;
test L.fiscfed4+1.886*L.fiscunits4=0;
test L.fiscfed4+3.524*L.fiscunits4=0;
test L.lnunits+0.223*L.fiscunits4=0;
test L.lnunits+0.564*L.fiscunits4=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.aged L.imf year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.lnunits L.fiscunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.aged L.imf L.lnpop lnarea year, pairwise;
test L.fiscfed4+1.886*L.fiscunits4=0;
test L.fiscfed4+3.524*L.fiscunits4=0;
test L.lnunits+0.223*L.fiscunits4=0;
test L.lnunits+0.564*L.fiscunits4=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.aged L.imf L.lnpop lnarea year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;

gen lngdp=ln(gdp);
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.lnunits L.fiscunits4 lngdp L.lngdp L2.lngdp L3.lngdp L.euherf L.aged L.codecision3 L.imf year, pairwise;

xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.lnunits L.fiscunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac nethfrac langfrac year, pairwise;
test nethfrac langfrac;
test L.fiscfed4+1.886*L.fiscunits4=0;
test L.fiscfed4+3.524*L.fiscunits4=0;
test L.lnunits+0.223*L.fiscunits4=0;
test L.lnunits+0.564*L.fiscunits4=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.lnunits L.fiscunits4 rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac year, pairwise;
test L.fiscfed4+1.886*L.fiscunits4=0;
test L.fiscfed4+3.524*L.fiscunits4=0;
test L.lnunits+0.223*L.fiscunits4=0;
test L.lnunits+0.564*L.fiscunits4=0;

/*using herfindahl index of regional populations*/
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac nethfrac langfrac year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;

xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac year, pairwise ;
xtpcse generalg L.generalg L2.generalg L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L.aged L.imf nrelfrac year, pairwise ;
/*interaction pics*/
generate MV=_n/20; replace MV=. if _n>20;
matrix b=e(b); matrix V=e(V); scalar b1=b[1,3]; scalar b3=b[1,5]; scalar b2=b[1,4]; scalar varb1=V[3,3]; scalar varb2=V[4,4]; scalar varb3=V[5,5]; scalar covb1b3=V[3,5]; scalar covb2b3=V[4,5];
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3; gen conb=b1+b3*MV if _n<21; gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<21; gen a=1.96*conse; gen upper=conb+a; gen lower=conb-a; 
twoway line conb MV, clwidth(medium) || line upper MV, clpattern(dash) clwidth(thin) || line lower MV, clpattern(dash) clwidth(thin) || , yscale(noline) 
xscale(noline) legend(col(1) order(1 2) label(1 "Marginal Effect of Fiscal Federalism") label(2 "95% Confidence Interval") label(3 " ")) yline(0, lcolor(black)) 
xtitle( "Herfindahl Index of Regional Population", size(3)  ) xsca(titlegap(2)) ysca(titlegap(2)) 
ytitle("Marginal Effect of Fiscal Federalism", size(3)) scheme(sj) graphregion(fcolor(white));
graph export  "FFJurisInter-c.eps", replace;
generate MV2=_n/20; replace MV2=. if _n>20;
gen conb2=b2+b3*MV2 if _n<21; gen conse2=sqrt(varb2+varb3*(MV2^2)+2*covb2b3*MV2) if _n<21; gen a2=1.96*conse2; gen upper2=conb2+a2; gen lower2=conb2-a2;
twoway line conb2 MV2, clwidth(medium) || line upper2 MV2, clpattern(dash) clwidth(thin) || line lower2 MV2, clpattern(dash) clwidth(thin) || , yscale(noline) 
xscale(noline) legend(col(1) order(1 2) label(1 "Marginal Effect of Herfindahl Index") label(2 "95% Confidence Interval") label(3 " ")) yline(0, lcolor(black))  xtitle( "Fiscal Federalism", size(3)) xsca(titlegap(2)) ysca(titlegap(2)) 
ytitle("Marginal Effect of Herfindahl Index", size(3)) scheme(sj) graphregion(fcolor(white));
graph export  "JurisFFInter-c.eps", replace;
/*Figure 3*/
set scheme sj;
twoway (function y = .477/(1-(1.137-0.18))+.621/(1-(1.137-0.18))*0.2827687+1.019/(1-(1.137-0.18))*.5343+(-.703+1.013-.289)/(1-(1.137-0.18))*15.48327-.359/(1-(1.137-0.18))*.422-0.00718/(1-(1.137-0.18))*39-.0661/(1-(1.137-0.18))*0.474+(-1.509+0.474*4.977)/(1-(1.137-0.18))*x, range(fiscdec4)) ///
(function y = .477/(1-(1.137-0.18))+.621/(1-(1.137-0.18))*0.2827687+1.019/(1-(1.137-0.18))*.5343+(-.703+1.013-.289)/(1-(1.137-0.18))*15.48327-.359/(1-(1.137-0.18))*.422-0.00718/(1-(1.137-0.18))*39-.0661/(1-(1.137-0.18))*0.223+(-1.509+0.223*4.977)/(1-(1.137-0.18))*x, range(fiscdec4)) ///
(function y = .477/(1-(1.137-0.18))+.621/(1-(1.137-0.18))*0.2827687+1.019/(1-(1.137-0.18))*.5343+(-.703+1.013-.289)/(1-(1.137-0.18))*15.48327-.359/(1-(1.137-0.18))*.422-0.00718/(1-(1.137-0.18))*39-.0661/(1-(1.137-0.18))*0.039+(-1.509+0.039*4.977)/(1-(1.137-0.18))*x, range(fiscdec4)), /// 
legend(order(1 "at mean Herf. Index" 2 "at median Herf. Index" 3 "at 10th percentile Herf. Index")) ///
ytitle("Government Consumption, % GDP", size(3)) xtitle("Fiscal Federalism", size(3)) note("Long-run asymptotic effects plotted. All other independent variables held at their means.") graphregion(fcolor(white));
graph export "functions-c.eps", replace;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
predict double xb2;
gen res2=generalg-xb2;
/*random effects*/
xtreg generalg L.generalg L2.generalg L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L.aged L.imf nrelfrac year, re vce(cluster id) ;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.2597*L.decherf=0;

xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged nrelfrac year , pairwise;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac year if fiscfed4>0, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xi: xtpcse generalg L.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac year i.id, pairwise;
xtivreg generalg L.generalg L2.generalg L3.generalg rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac year (L.fiscfed4 L.herf L.fischerf = langfrac nethfrac L.lnpop lnarea lnsec), re;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;

/*log linear*/

drop lngdp;
gen lngc=ln(1+generalg);
gen lntotals=ln(1+totals);
gen lnsub=ln(1+tsub);
gen lnstsb=ln(1+stsb);
gen lnig=ln(1+iggdp);
gen lnff=ln(1+fiscfed4);
gen lnh=ln(1+herf);
gen lnfflnh=lnff*lnh;
gen lngdp=ln(rgdpch);
gen lnimf=ln(1+imf/100);
gen lnaged=ln(1+aged);
gen lnrel=ln(1+nrelfrac);
sum lnff lnh lnfflnh lngc lntotals lnsub lnstsb lnig lnimf lnaged lnrel lngdp;
xtpcse lngc L.lngc L2.lngc L3.lngc L.lnff L.lnh L.lnfflnh lngdp L.lngdp L2.lngdp L3.lngdp L.lnimf L.lnaged lnrel year, pairwise;
test L.lnff+0.05*L.lnfflnh=0;
test L.lnh+0.41*L.lnfflnh=0;
xtpcse lntotals L.lntotals L2.lntotals L.lnff L.lnh L.lnfflnh lngdp L.lngdp L.lnimf L.lnaged lnrel year, pairwise;
test L.lnff+0.05*L.lnfflnh=0;
test L.lnh+0.41*L.lnfflnh=0;
xtpcse lnsub L.lnsub L.lnff L.lnh L.lnfflnh lngdp L.lngdp L.lnimf L.lnaged lnrel year, pairwise;
test L.lnff+0.05*L.lnfflnh=0;
test L.lnh+0.41*L.lnfflnh=0;
xtpcse lnstsb L.lnstsb L2.lnstsb L.lnff L.lnh L.lnfflnh lngdp L.lngdp L.lnimf L.lnaged lnrel year, pairwise;
test L.lnff+0.05*L.lnfflnh=0;
test L.lnh+0.41*L.lnfflnh=0;
xtpcse lnig L.lnig L.lnff L.lnh L.lnfflnh lngdp L.lngdp L.lnimf L.lnaged lnrel year, pairwise;
test L.lnff+0.05*L.lnfflnh=0;
test L.lnh+0.41*L.lnfflnh=0;

/*yet more controls*/
sort id year;
by id: ipolate tradsec year, gen(tradseci);
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac tradseci year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
gen newworld=0;
replace newworld=1 if id==2; replace newworld=1 if id==7; replace newworld=1 if id==28; replace newworld=1 if id==42;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac newworld year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf ethfrac relfrac year, pairwise;
test ethfrac relfrac;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac solt year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac openk L.openk L.lnpop year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac postsoc year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac wars year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;

xi i.year;
xtreg generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac _Iyear*, re vce(cluster id);
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;

/*yet more controls: institutions*/
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac L.plurality L.lnmdm L.system year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac L.execrlc year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;

/*alternative measure of fiscal federalism*/
xtpcse generalg L.generalg L2.generalg L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L.euherf L.aged L.imf nrelfrac year, pairwise;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
xtivreg generalg L.generalg L2.generalg rgdpch L.rgdpch L2.rgdpch L.euherf L.aged L.imf nrelfrac year (L.fiscdec4 L.herf L.decherf = nethfrac langfrac L.lnpop lnarea lnsec), re;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
xtpcse generalg L.generalg L2.generalg L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L.imf L.aged nrelfrac year, pairwise;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
regress generalg L.generalg L2.generalg L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L.aged L.imf nrelfrac _Iyear*, cluster(id);
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;

/*robustness checks: fiscfed dummies*/
gen fiscdum1=.;
replace fiscdum1=0 if fiscfed4<0.499;
replace fiscdum1=1 if fiscfed4>0.499;
gen fiscdum2=.;
replace fiscdum2=0 if fiscfed4<.749;
replace fiscdum2=1 if fiscfed4>.749;
gen dumherf1=fiscdum1*herf;
gen dumherf2=fiscdum2*herf;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscdum1 L.herf L.dumherf1 rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac year, pairwise;
test L.fiscdum1+0.475*L.dumherf1=0;
test L.fiscdum1+0.036*L.dumherf1=0;
test L.herf+L.dumherf1=0;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscdum2 L.herf L.dumherf2 rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac year, pairwise;
test L.fiscdum2+0.475*L.dumherf2=0;
test L.fiscdum2+0.036*L.dumherf2=0;
test L.herf+L.dumherf2=0;
xtpcse totals L.totals L2.totals L.fiscdum1 L.herf L.dumherf1 rgdpch L.rgdpch L.aged L.imf nrelfrac year, pairwise;
test L.fiscdum1+0.475*L.dumherf1=0;
test L.fiscdum1+0.036*L.dumherf1=0;
test L.herf+L.dumherf1=0;
xtpcse stsb L.stsb L2.stsb L.fiscdum1 L.herf L.dumherf1 rgdpch L.rgdpch L.aged L.imf nrelfrac year, pairwise;
test L.fiscdum1+0.475*L.dumherf1=0;
test L.fiscdum1+0.036*L.dumherf1=0;
test L.herf+L.dumherf1=0;
xtpcse tsub L.tsub L.fiscdum1 L.herf L.dumherf1 rgdpch L.rgdpch L.imf nrelfrac year, pairwise;
test L.fiscdum1+0.475*L.dumherf1=0;
test L.fiscdum1+0.036*L.dumherf1=0;
test L.herf+L.dumherf1=0;
xtpcse iggdp L.iggdp L.fiscdum1 L.herf L.dumherf1 rgdpch L.rgdpch L.imf nrelfrac L.lnpop year, pairwise;
test L.fiscdum1+0.475*L.dumherf1=0;
test L.fiscdum1+0.036*L.dumherf1=0;
test L.herf+L.dumherf1=0;

/*robustness checks: no GDP variables*/
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf L.aged L.imf nrelfrac year, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;

/*robustness checks: dropping countries*/
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=42, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=41, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=40, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=39, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=38, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=37, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=36, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=35, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=34, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=33, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=32, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=31, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=30, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=29, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=28, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=27, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=26, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=25, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=24, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=23, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=22, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=21, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=20, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=19, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=18, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=17, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=16, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=15, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=14, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=13, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=12, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=11, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=10, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=9, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=8, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=7, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=6, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=5, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=4, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=3, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=2, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=1, pairwise ;
xtpcse generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac if id~=8 & id~=9 & id~=10 & id~=12 & id~=22 & id~=23 & id~=26 & id~=32 & id~=35 & id~=40, pairwise;
xtivreg generalg L.generalg L2.generalg L3.generalg rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac (L.fiscfed4 L.herf L.fischerf = nethfrac langfrac L.lnpop lnarea lnsec) if id~=8 & id~=9 & id~=10 & id~=12 & id~=22 & id~=23 & id~=26 & id~=32 & id~=35 & id~=40, re;

/*govt consumption - oecd*/
xtpcse cggdp L.cggdp L2.cggdp L3.cggdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse cggdp L.cggdp L2.cggdp L3.cggdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac, pairwise;

/*social spending - oecd*/

xtpcse totalsocial L.totals L2.totals L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;

xtpcse totalsocial L.totals L2.totals L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac if fiscfed4>0, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtivreg totalsocial L.totals L2.totals rgdpch L.rgdpch L.aged L.imf nrelfrac (L.fiscfed4 L.herf L.fischerf = nethfrac langfrac L.lnpop lnarea lnsec), re;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse totalsocial L.totals L2.totals L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac nethfrac langfrac, pairwise;
xtpcse totalsocial L.totals L2.totals L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac L.openk L.lnpop, pairwise;
xtreg totalsocial L.totals L2.totals L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac _Iyear*, re vce(cluster id);
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse totalsocial L.totals L2.totals L3.totals L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.aged L.imf nrelfrac year, pairwise;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
/*Figure 2*/
predict double xb1;
gen res1=totalsocial-xb1;
/*unit root checks*/
xtunitroot fisher totalsocial if res1~=., dfuller demean lags(2) trend;
xtunitroot fisher res1 , dfuller lags(0);
/*baseline*/
xtpcse totalsocial L.totals L2.totals L3.totals year if xb1~=., pairwise;

preserve;
collapse (mean) res1 (mean) res2, by(country);
gen pos=3; replace pos=2 if country=="New Zealand"; replace pos=12 if country=="Austria"; replace pos=12 if country=="Australia"; 
replace pos=4 if country=="Denmark"; replace pos=4 if country=="Canada"; replace pos=6 if country=="Belgium"; replace pos=9 if country=="Germany"; 
replace pos=9 if country=="West Germany"; replace pos=4 if country=="Norway"; replace pos=12 if country=="Finland"; replace pos=6 if country=="Switzerland";
replace pos=6 if country=="Luxembourg";
scatter res1 res2 if res2>-.4 & res2<.4, mlabel(country) mlabsize(small) mlabvposition(pos) msize(vsmall) ytitle("Mean Social Spending Disturbances", size(3)) 
xtitle("Mean Government Consumption Disturbances", size(3)) xlabel(-.4 -.2 0 .2 .4) graphregion(fcolor(white));
graph export "outliers-b.eps", replace;
restore;
xtpcse totalsocial L.totals L2.totals L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.aged L.imf nrelfrac tradseci, pairwise;
xtpcse totalsocial L.totals L2.totals L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.aged L.imf nrelfrac newworld, pairwise;
xtpcse totalsocial L.totals L2.totals L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.aged L.imf nrelfrac solt, pairwise;
/*random effects*/

xtreg totalsocial L.totals L2.totals L3.totals L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.aged L.imf nrelfrac year, re vce(cluster id);
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
xtreg totalsocial L.totals L2.totals L3.totals L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.aged L.imf nrelfrac _Iyear*, re vce(cluster id);
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;

/*social benefits & transfers - oecd*/

xtpcse stsbgdp L.stsbgdp L2.stsbgdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.aged L.imf nrelfrac, pairwise;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
predict xb3, xb;
/*baseline*/
xtpcse stsbgdp L.stsbgdp L2.stsbgdp if xb3~=., pairwise;
xtunitroot fisher stsbgdp if xb3~=., dfuller demean lags(1);
drop xb3;
xtpcse stsbgdp L.stsbgdp L2.stsbgdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac if fiscfed4>0, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse stsbgdp L.stsbgdp L2.stsbgdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac L.openk, pairwise;
xtpcse stsbgdp L.stsbgdp L2.stsbgdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac tradseci, pairwise;
xtpcse stsbgdp L.stsbgdp L2.stsbgdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac newworld, pairwise;
xtpcse stsbgdp L.stsbgdp L2.stsbgdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac solt, pairwise;
/*random effects*/
xtreg stsbgdp L.stsbgdp L2.stsbgdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.aged L.imf nrelfrac _Iyear*, re vce(cluster id);
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;

xtreg stsbgdp L.stsbgdp L2.stsbgdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.aged L.imf nrelfrac, re vce(cluster id);
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
xtreg stsbgdp L.stsbgdp L2.stsbgdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.aged L.imf nrelfrac _Iyear*, re vce(cluster id);
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;

/*subsidies - oecd*/

xtpcse tsubgdp L.tsub L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.imf nrelfrac, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse tsubgdp L.tsub L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.imf nrelfrac if fiscfed4>0, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse tsubgdp L.tsub L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.imf nrelfrac nethfrac langfrac, pairwise;
xtpcse tsubgdp L.tsub L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.imf nrelfrac L.openk L.lnpop, pairwise;
xtpcse tsubgdp L.tsub L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.imf nrelfrac, pairwise;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
predict xb4, xb;
/*baseline*/
xtpcse tsubgdp L.tsub if xb4~=., pairwise;
xtunitroot fisher tsub if xb4~=., dfuller lags(1);
drop xb4;
/*random effects*/
xtreg tsubgdp L.tsub L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.imf nrelfrac, re vce(cluster id);
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
xtreg tsubgdp L.tsub L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.imf nrelfrac _Iyear*, re vce(cluster id);
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;

/*govt investment - oecd*/

xtpcse iggdp L.iggdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.imf nrelfrac L.lnpop L.lnarea , pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse iggdp L.iggdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.imf nrelfrac L.lnpop L.lnarea if fiscfed4>0, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse iggdp L.iggdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.imf nrelfrac nethfrac langfrac L.lnpop L.lnarea , pairwise;
xtpcse iggdp L.iggdp L2.iggdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.imf nrelfrac  L.lnpop L.lnarea , pairwise;
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
predict xb5, xb;
/*baseline*/
xtpcse iggdp L.iggdp L2.iggdp if xb5~=., pairwise;
xtunitroot fisher iggdp if xb5~=., dfuller lags(1);
drop xb5;
/*random effects*/
xtreg iggdp L.iggdp L2.iggdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.imf nrelfrac  L.lnpop L.lnarea , re vce(cluster id);
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;
xtreg iggdp L.iggdp L2.iggdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.imf nrelfrac  L.lnpop L.lnarea _Iyear*, re vce(cluster id);
test L.fiscdec4+0.475*L.decherf=0;
test L.fiscdec4+0.036*L.decherf=0;
test L.herf+0.0901*L.decherf=0;
test L.herf+0.2597*L.decherf=0;

/*govt wage bill - oecd*/
xtpcse cgwgdp L.cgwgdp L2.cgwgdp L3.cgwgdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse cgwgdp L.cgwgdp L2.cgwgdp L3.cgwgdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac, pairwise;

/*govt employment - oecd*/
xtpcse eget L.eget L2.eget L3.eget L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse eget L.eget L2.eget L3.eget L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac, pairwise;

/*govt non-wage consumption - oecd*/
xtpcse cgnwgdp L.cgnwgdp L2.cgnwgdp L3.cgnwgdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac, pairwise;
test L.fiscfed4+0.475*L.fischerf=0;
test L.fiscfed4+0.036*L.fischerf=0;
test L.herf+0.223*L.fischerf=0;
test L.herf+0.564*L.fischerf=0;
xtpcse cgnwgdp L.cgnwgdp L2.cgnwgdp L3.cgnwgdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.aged L.imf nrelfrac, pairwise;

collapse (mean) fiscfed4 units taxdec imf generalg totalsocialexpenditure stsbgdp tsubgdp iggdp cgwgdp cgnwgdp eget nrelfrac, by (country);

corr generalg totals stsbgdp tsubgdp iggdp cgwgdp cgnwgdp eget;


/*multiply imputed data*/
clear; use fiscfedout;
mi import flong, m(imp) id(year id) imp(fiscfed4-unem);
mi xtset id year;

gen lnpop=ln(pop);
gen lnpopul=ln(population);
gen lnarea=ln(area);
gen lnsec=ln(secmov+1);

gen fischerf=fiscfed4*herf;
gen fiscdec4=fiscfed4*taxdec/100;
gen decherf=fiscdec4*herf;

sort id year;

xi i.year;

replace gdp=gdp/1000;
replace rgdpch=rgdpch/1000;
replace imf=imf/100;
replace year=year-1950;
/*baseline*/
mi estimate: xtreg generalg L.generalg L2.generalg L3.generalg, re vce(cluster id) ;
mi estimate, cmdok: xtpcse totals L.totals, pairwise;
mi estimate: xtreg totals L.totals, re vce(cluster id);
mi estimate, cmdok: xtpcse stsbgdp L.stsbgdp, pairwise;
mi estimate: xtreg stsbgdp L.stsbgdp, re vce(cluster id);
mi estimate, cmdok: xtpcse tsub L.tsub, pairwise;
mi estimate: xtreg tsub L.tsub, re vce(cluster id);
mi estimate, cmdok: xtpcse iggdp L.iggdp L2.iggdp, pairwise;
mi estimate: xtreg iggdp L.iggdp L2.iggdp, re vce(cluster id);

mi estimate (ffhiherf: _b[L.fiscfed4]+0.475*_b[L.fischerf]) (ffloherf: _b[L.fiscfed4]+0.036*_b[L.fischerf]) (herfhiff: _b[L.herf]+0.564*_b[L.fischerf]) (herfloff: _b[L.herf]+0.223*_b[L.fischerf]), saving(miest, replace): xtgee generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.Ag_dpn L.imf nrelfrac, family(gau) link(i) corr(exc) vce(robust) iter(1000) tol(1e-5);
mi estimate (ffhiherf: _b[L.fiscfed4]+0.475*_b[L.fischerf]) (ffloherf: _b[L.fiscfed4]+0.036*_b[L.fischerf]) (herfhiff: _b[L.herf]+0.564*_b[L.fischerf]) (herfloff: _b[L.herf]+0.223*_b[L.fischerf]), saving(miest20, replace): xtreg generalg L.generalg L2.generalg L3.generalg L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.Ag_dpn L.imf nrelfrac _Iyear*, re vce(cluster id);
mi estimate (ffhiherf: _b[L.fiscfed4]+0.475*_b[L.fischerf]) (ffloherf: _b[L.fiscfed4]+0.036*_b[L.fischerf]) (herfhiff: _b[L.herf]+0.564*_b[L.fischerf]) (herfloff: _b[L.herf]+0.223*_b[L.fischerf]), saving(miest2, replace) cmdok: xtpcse totals L.totals L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.Ag_dpn L.imf nrelfrac, pairwise;
mi estimate (ffhiherf: _b[L.fiscfed4]+0.475*_b[L.fischerf]) (ffloherf: _b[L.fiscfed4]+0.036*_b[L.fischerf]) (herfhiff: _b[L.herf]+0.564*_b[L.fischerf]) (herfloff: _b[L.herf]+0.223*_b[L.fischerf]), saving(miest3, replace) cmdok: xtpcse stsbgdp L.stsbgdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.Ag_dpn L.imf nrelfrac, pairwise;
mi estimate (ffhiherf: _b[L.fiscfed4]+0.475*_b[L.fischerf]) (ffloherf: _b[L.fiscfed4]+0.036*_b[L.fischerf]) (herfhiff: _b[L.herf]+0.564*_b[L.fischerf]) (herfloff: _b[L.herf]+0.223*_b[L.fischerf]), saving(miest4, replace) cmdok: xtpcse tsubgdp L.tsubgdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.imf nrelfrac, pairwise;
mi estimate (ffhiherf: _b[L.fiscfed4]+0.475*_b[L.fischerf]) (ffloherf: _b[L.fiscfed4]+0.036*_b[L.fischerf]) (herfhiff: _b[L.herf]+0.564*_b[L.fischerf]) (herfloff: _b[L.herf]+0.223*_b[L.fischerf]), saving(miest5, replace) cmdok: xtpcse iggdp L.iggdp L2.iggdp L.fiscfed4 L.herf L.fischerf rgdpch L.rgdpch L.imf nrelfrac, pairwise;

mi estimate (ffhiherf: _b[L.fiscdec4]+0.475*_b[L.decherf]) (ffloherf: _b[L.fiscdec4]+0.036*_b[L.decherf]) (herfhiff: _b[L.herf]+0.2597*_b[L.decherf]) (herfloff: _b[L.herf]+0.0901*_b[L.decherf]), saving(miest11, replace): xtgee generalg L.generalg L2.generalg L3.generalg L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.Ag_dpn L.imf nrelfrac, family(gau) link(i) corr(exc) vce(robust) iter(1000) tol(1e-5);
mi estimate (ffhiherf: _b[L.fiscdec4]+0.475*_b[L.decherf]) (ffloherf: _b[L.fiscdec4]+0.036*_b[L.decherf]) (herfhiff: _b[L.herf]+0.2597*_b[L.decherf]) (herfloff: _b[L.herf]+0.0901*_b[L.decherf]), saving(miest21, replace): xtreg generalg L.generalg L2.generalg L3.generalg L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L2.rgdpch L3.rgdpch L.euherf L.Ag_dpn L.imf nrelfrac _Iyear*, re vce(cluster id);
mi estimate (ffhiherf: _b[L.fiscdec4]+0.475*_b[L.decherf]) (ffloherf: _b[L.fiscdec4]+0.036*_b[L.decherf]) (herfhiff: _b[L.herf]+0.2597*_b[L.decherf]) (herfloff: _b[L.herf]+0.0901*_b[L.decherf]), saving(miest12, replace) cmdok: xtpcse totals L.totals L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.Ag_dpn L.imf nrelfrac, pairwise;
mi estimate (ffhiherf: _b[L.fiscdec4]+0.475*_b[L.decherf]) (ffloherf: _b[L.fiscdec4]+0.036*_b[L.decherf]) (herfhiff: _b[L.herf]+0.2597*_b[L.decherf]) (herfloff: _b[L.herf]+0.0901*_b[L.decherf]), saving(miest22, replace): xtreg totals L.totals L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.Ag_dpn L.imf nrelfrac _Iyear*, re vce(cluster id);
mi estimate (ffhiherf: _b[L.fiscdec4]+0.475*_b[L.decherf]) (ffloherf: _b[L.fiscdec4]+0.036*_b[L.decherf]) (herfhiff: _b[L.herf]+0.2597*_b[L.decherf]) (herfloff: _b[L.herf]+0.0901*_b[L.decherf]), saving(miest13, replace) cmdok: xtpcse stsbgdp L.stsbgdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.Ag_dpn L.imf nrelfrac, pairwise;
mi estimate (ffhiherf: _b[L.fiscdec4]+0.475*_b[L.decherf]) (ffloherf: _b[L.fiscdec4]+0.036*_b[L.decherf]) (herfhiff: _b[L.herf]+0.2597*_b[L.decherf]) (herfloff: _b[L.herf]+0.0901*_b[L.decherf]), saving(miest23, replace): xtreg stsbgdp L.stsbgdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.Ag_dpn L.imf nrelfrac _Iyear*, re vce(cluster id);
mi estimate (ffhiherf: _b[L.fiscdec4]+0.475*_b[L.decherf]) (ffloherf: _b[L.fiscdec4]+0.036*_b[L.decherf]) (herfhiff: _b[L.herf]+0.2597*_b[L.decherf]) (herfloff: _b[L.herf]+0.0901*_b[L.decherf]), saving(miest14, replace) cmdok: xtpcse tsubgdp L.tsubgdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.imf nrelfrac, pairwise;
mi estimate (ffhiherf: _b[L.fiscdec4]+0.475*_b[L.decherf]) (ffloherf: _b[L.fiscdec4]+0.036*_b[L.decherf]) (herfhiff: _b[L.herf]+0.2597*_b[L.decherf]) (herfloff: _b[L.herf]+0.0901*_b[L.decherf]), saving(miest24, replace): xtreg tsubgdp L.tsubgdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.imf nrelfrac _Iyear*, re vce(cluster id);
mi estimate (ffhiherf: _b[L.fiscdec4]+0.475*_b[L.decherf]) (ffloherf: _b[L.fiscdec4]+0.036*_b[L.decherf]) (herfhiff: _b[L.herf]+0.2597*_b[L.decherf]) (herfloff: _b[L.herf]+0.0901*_b[L.decherf]), saving(miest15, replace) cmdok: xtpcse iggdp L.iggdp L2.iggdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.imf nrelfrac L.lnpop lnarea, pairwise;
mi estimate (ffhiherf: _b[L.fiscdec4]+0.475*_b[L.decherf]) (ffloherf: _b[L.fiscdec4]+0.036*_b[L.decherf]) (herfhiff: _b[L.herf]+0.2597*_b[L.decherf]) (herfloff: _b[L.herf]+0.0901*_b[L.decherf]), saving(miest25, replace): xtreg iggdp L.iggdp L2.iggdp L.fiscdec4 L.herf L.decherf rgdpch L.rgdpch L.imf nrelfrac L.lnpop lnarea _Iyear*, re vce(cluster id);

log close;
